#
# spec file for package python-dparse
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  test
Name:           python-dparse
Version:        0.6.4
Release:        1.5
Summary:        Python dependency file parser
License:        MIT
URL:            https://github.com/jayfk/dparse
Source:         https://files.pythonhosted.org/packages/source/d/dparse/dparse-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-packaging
Requires:       (python-tomli if python-base < 3.11)
Recommends:     python-pipenv
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module packaging}
BuildRequires:  %{python_module pytest}
%endif
%python_subpackages

%description
A parser for Python dependency files.

%prep
%autosetup -p1 -n dparse-%{version}
# Note vendor/toml.py could be unvendored

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
# There is a bug in the pipenv support, related to writing a new toml file.
# Both dparse and pipenv have a vendored copy of different toml libraries.
# and even more, we do not have pipenv in our distribution
%pytest --deselect 'tests/test_updater.py::test_update_pipfile'
%endif

%files %{python_files}
%license LICENSE
%doc README.rst HISTORY.rst
%{python_sitelib}/dparse
%{python_sitelib}/dparse-%{version}.dist-info

%changelog
* Tue Nov 12 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.6.4
  * Fix "AttributeError: SafeConfigParser instance has no attribute 'values'"
  * Support poetry.lock version >= 1.5
  * Add pyproject parser
  * Test pyproject parser
  * Add to readme
  * Remove python2-ism in the code
  * Migrate to pyproject.toml
  * Maybe you don't even need build-system
  * Add and fix workflows
  * Replace ConfigParser's 'readfp' by 'read_string'
  * Run tests on PR events
  * Trigger label check on fork PRs
  * ci(.github): revamp workflows and add hatch
  * perf(.github): prepare release workflows
  * perf(pyproject.toml): Set the start version of the new dparse release
  * ci(ci.yml): Set SLUG to release when the correct even is triggered
  * docs(CHANGELOG.md): Reset CHANGELOG.md
  * build(pyproject.toml): Fix steps for changelog generation
  * ci(release.yml): Download artifact from another workflow
- Add python-hatchling to BuildRequires
- Drop fix-configparser-parsing.patch, merged upstream
* Mon Jan 15 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to autosetup and pyproject macros.
- Stop using greedy globs in %%files.
- Add patch fix-configparser-parsing.patch:
  * Use non-deprecated/removed functions from ConfigParser.
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 0.6.3:
  * Use the modern tomli/tomllib to parse TOML files.
  * Drop Python 3.5 from our CI.
* Thu Oct 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 0.6.2
  * Fixed bug: always call the parent from the PATH in the resolve_file function.
* Tue Sep 27 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 0.6.1
  * Use non-deprecated ConfiParser method
- update to 0.6.0
  * Fork from upstream dparse that is unresponsive
  * Rename package to dparse2
  * Fix security issue for GHSL-2021-111https://github.com/pyupio/dparse/issues/50
  * Drop support for Python < 3.6 and add support for up to 3.10
  * Drop support for updating requirements files
  * format code with black, sort imports
* Thu Sep 17 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.1:
  * Fixed package metadata removing 2.7 support
  * Install pipenv only when asked for with extras
* Fri Apr  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.5.0
  * Dropped Python 2.7, 3.3, 3.4 support
  * Removed six package
  * Removed pinned dependencies of tests
  * Dropped setup.py tests support in favor of tox
* Tue Apr 16 2019 Matej Cepl <mcepl@suse.com>
- Although pipenv is required by upstream, tests pass even
  without it, and we don't have it packaged yet.
* Tue Feb 12 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v0.4.1
  * Fixed a packaging error
- for 0.4.0
  * pipenv is now an optional dependency that's only used when updating a Pipfile
  * Added support for invalid toml Pipfiles
- for 0.3.0
  * Added support for setup.cfg files
  * Dependencies from Pipfiles now include the section
  * Multiline requirements are now ignored if they are marked
  * Added experimental support for Pipfiles
- Remove unnecessary build dependency on python-devel and pytest-runner
- Added Recommends for pipenv, and disabled one test related to Pipfile
  support.
- Use %%license
* Wed Jan 17 2018 toddrme2178@gmail.com
- Initial version for 0.2.1
